@@ -134,9 +134,9 @@ class AWSProvider(nepho.core.provider.AbstractProvider):
         cf_dict = parse_cf_json(raw_template)
         return get_cf_json(cf_dict, pretty=True)
 
-    def deploy(self, debug=None):
+    def deploy(self, app_obj):
         """Deploy a given pattern."""
-        if debug is True:
+        if app_obj.pargs.debug is True:
             boto.set_stream_logger('aws_provider')
 
         context = self.scenario.context
@@ -151,7 +151,11 @@ class AWSProvider(nepho.core.provider.AbstractProvider):
         params = list()
         for item in context['parameters'].items():
             if item[0] in template_param_names:
-                params.append(item)
+                if item[1] is None:
+                    print colored("Error: ", "red"), "Required parameter %s is not set" % item[0]
+                    exit(1)
+                else:
+                    params.append(item)
             else:
                 print colored("Warning: ", "yellow"), "Nepho parameter %s is not present in the CloudFormation template" % item[0]
 
@@ -226,7 +230,7 @@ class AWSProvider(nepho.core.provider.AbstractProvider):
             exit(1)
         return stack_id
 
-    def status(self):
+    def status(self, app_obj):
         """Check on the status of a stack within CloudFormation."""
 
         try:
@@ -234,7 +238,7 @@ class AWSProvider(nepho.core.provider.AbstractProvider):
         except exc.CaughtSignal:
             exit()
 
-    def access(self):
+    def access(self, app_obj):
         """Check on the status of a stack within CloudFormation."""
 
         # Return object of type boto.cloudformation.stack.Stack
@@ -250,7 +254,7 @@ class AWSProvider(nepho.core.provider.AbstractProvider):
             print "Error communication with the CloudFormation service: %s" % (be)
             exit(1)
 
-    def destroy(self):
+    def destroy(self, app_obj):
         """Delete a CloudFormation stack."""
         self.connection.delete_stack(stack_name_or_id=self.stack_name)
 
