@@ -11,5 +11,5 @@ converted = pypandoc.convert(markdown, 'rst')
 f = open(rst, 'w+')
 f.write(converted)
 f.close()
-os.system('python setup.py register sdist bdist_egg upload')
+os.system('python setup.py register sdist upload')
 os.remove(rst)
